@@ -15,17 +15,23 @@ class Connection:
     def __init__(self,
                  database: Optional[Union[str, Path]] = None,
                  uri: bool = False,
-                 timeout: float = 5.0,
+                 timeout: int = 0,
                  detect_types: int = 0,
                  check_same_thread: bool = True,
                  autocommit: bool = False,
+                 nr_threads: int = 0,
+                 memorylimit: int = 0,
+                 querytimeout: int = 0,
+                 logging: Optional[Path] = None,
+                 username: Optional[str] = None,
+                 password: Optional[str] = None,
+                 port: Optional[int] = None,
                  ):
         """
         Args:
             database: The path to you database. Leave empty or use the `:memory:` string to start an in-memory database.
             uri: if true, database is interpreted as a URI. This allows you to specify options.
-            timeout: The connection timeout, which is unused and meaningless in the case of MonetDBe and exists for
-                     compatibility reasons.
+            timeout: The session / connection timeout in seconds, 0 = no limit (default)
             detect_types:  defaults to 0 (i. e. off, no type detection), you can set it to any combination of
                            PARSE_DECLTYPES and PARSE_COLNAMES to turn type detection on.
             check_same_thread: By default, check_same_thread is True and only the creating thread may use the
@@ -33,8 +39,16 @@ class Connection:
                                When using multiple threads with the same connection writing operations should be
                                serialized by the user to avoid data corruption.
             autocommit: Enable autocommit mode
+            nr_threads: to control the level of parallelism, 0 = all cores (default)
+            memorylimit: to control the memory footprint allowed in :memory: mode in MB, 0 = no limit (default)
+            querytimeout: The query timeout in seconds, 0 = no limit (default)
+            logging: the file location for the tracer files (not used yet)
+            username: used to connect to a remote server (not used yet)
+            password: credentials to reach the remote server (not used yet)
+            port: TCP/IP port to listen for connections (not used yet)
+
         """
-        if uri:
+        if uri or port or username or password or logging:
             raise NotImplemented  # todo
 
         if not check_same_thread:
@@ -54,8 +68,19 @@ class Connection:
         else:
             raise TypeError
 
-        from monetdbe._cffi import MonetEmbedded
-        self.lowlevel: Optional[MonetEmbedded] = MonetEmbedded(dbdir=database)
+        from monetdbe._cffi import check_if_we_can_import_lowlevel
+
+        check_if_we_can_import_lowlevel()
+
+        from monetdbe._cffi.frontend import Frontend
+
+        self.lowlevel: Optional[Frontend] = Frontend(
+            dbdir=database,
+            memorylimit=memorylimit,
+            nr_threads=nr_threads,
+            querytimeout=querytimeout,
+            sessiontimeout=timeout
+        )
 
         self.result = None
         self.row_factory: Optional[Type[Row]] = None
@@ -124,8 +149,8 @@ class Connection:
         return self.execute("COMMIT")
 
     def close(self, *args, **kwargs) -> None:
-        del self.lowlevel
-        # todo (gijs): typing
+        if self.lowlevel:
+            self.lowlevel.close()
         self.lowlevel = None
 
     def cursor(self, factory: Optional[Type['Cursor']] = None) -> 'Cursor':
@@ -147,7 +172,7 @@ class Connection:
         cursor = factory(con=self)
         if not cursor:
             raise TypeError
-        if not self.lowlevel:
+        if not hasattr(self, 'lowlevel') or not self.lowlevel:
             raise exceptions.ProgrammingError
         return cursor
 
@@ -210,7 +235,15 @@ class Connection:
             value: a boolean value
         """
         self._check()
-        return self.lowlevel.set_autocommit(value)   # type: ignore
+        return self.lowlevel.set_autocommit(value)  # type: ignore
+
+    def read_csv(self, table, *args, **kwargs):
+        from monetdbe.cursor import Cursor  # we need to import here, otherwise circular import
+        cur = Cursor(con=self).read_csv(table, *args, **kwargs)
+
+    def write_csv(self, table, *args, **kwargs):
+        from monetdbe.cursor import Cursor  # we need to import here, otherwise circular import
+        cur = Cursor(con=self).write_csv(table, *args, **kwargs)
 
     # these are required by the python DBAPI
     Warning = exceptions.Warning
